'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _parser = require('../parsec/parser');

var _parser2 = _interopRequireDefault(_parser);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
// Facilities
//

var eol = _parser2.default.char('\n'); /*
                                        * Parsec
                                        * https://github.com/d-plaindoux/parsec
                                        *
                                        * Copyright (c) 2016 Didier Plaindoux
                                        * Licensed under the LGPL2 license.
                                        */

function title(line, level) {
    return { title: line, level: level };
}

function italicText(text) {
    return { italic: text };
}

function boldText(text) {
    return { bold: text };
}

function strikeText(text) {
    return { strike: text };
}

function normalText(c) {
    return { text: c.join('') };
}

function italic() {
    return _parser2.default.try(_parser2.default.string("*").thenRight(_parser2.default.lazy(text, ["*"])).thenLeft(_parser2.default.string("*")).or(_parser2.default.string("_").thenRight(_parser2.default.lazy(text, ["_"])).thenLeft(_parser2.default.string("_"))).map(italicText));
}

function bold() {
    return _parser2.default.try(_parser2.default.string("**").thenRight(_parser2.default.lazy(text, ["**"])).thenLeft(_parser2.default.string("**")).or(_parser2.default.string("__").thenRight(_parser2.default.lazy(text, ["__"])).thenLeft(_parser2.default.string("__"))).map(boldText));
}

function strike() {
    return _parser2.default.try(_parser2.default.string("~~").thenRight(_parser2.default.lazy(text, ["~~"])).thenLeft(_parser2.default.string("~~")).map(strikeText));
}

function text(separator) {
    if (separator) {
        return _parser2.default.not(eol.or(_parser2.default.string(separator))).optrep().map(normalText);
    } else {
        return _parser2.default.not(eol).then(_parser2.default.charNotIn('\n*_~').optrep()).map(function (c) {
            return [c[0]].concat(c[1]);
        }).map(normalText);
    }
}

function line() {
    return bold().or(italic()).or(strike()).or(text()).optrep().thenLeft(eol.opt());
}

function titleSharp() {
    return _parser2.default.char('#').rep().then(line()).map(function (c) {
        return [title(c[1], c[0].length)];
    });
}

function titleAlt() {
    return _parser2.default.try(line().flatmap(function (l) {
        return _parser2.default.char('=').rep().map(function () {
            return [title(l, 1)];
        }).or(_parser2.default.char('-').rep().map(function () {
            return [title(l, 2)];
        })).thenLeft(eol.opt());
    }));
}

exports.default = titleSharp().or(titleAlt()).or(line()).thenLeft(_parser2.default.eos);
//# sourceMappingURL=markdown.js.map