'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _index = require('../../lib/stream/index');

var _index2 = _interopRequireDefault(_index);

var _markdown = require('../../lib/standard/markdown');

var _markdown2 = _interopRequireDefault(_markdown);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
  ======== A Handy Little Nodeunit Reference ========
  https://github.com/caolan/nodeunit

  Test methods:
    test.expect(numAssertions)
    test.done()
  Test assertions:
    test.ok(value, [message])
    test.equal(actual, expected, [message])
    test.notEqual(actual, expected, [message])
    test.deepEqual(actual, expected, [message])
    test.notDeepEqual(actual, expected, [message])
    test.strictEqual(actual, expected, [message])
    test.notStrictEqual(actual, expected, [message])
    test.throws(block, [error], [message])
    test.doesNotThrow(block, [error], [message])
    test.ifError(value)
*/

exports.default = {
  setUp: function setUp(done) {
    done();
  },

  'title 1 should be accepted': function title1ShouldBeAccepted(test) {
    test.expect(1);
    // tests here
    test.ok(_markdown2.default.parse(_index2.default.ofString('# Title \n'), 0).isAccepted(), 'should be accepted.');
    test.done();
  },

  'title 1 should be retrieved': function title1ShouldBeRetrieved(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('# Title \n'), 0).value, [{ title: [{ text: " Title " }], level: 1 }], 'should be a title1.');
    test.done();
  },

  'title 2 should be accepted': function title2ShouldBeAccepted(test) {
    test.expect(1);
    // tests here
    test.ok(_markdown2.default.parse(_index2.default.ofString('## Title \n'), 0).isAccepted(), 'should be accepted.');
    test.done();
  },

  'title 2 should be retrieved': function title2ShouldBeRetrieved(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('## Title \n'), 0).value, [{ title: [{ text: " Title " }], level: 2 }], 'should be a title2.');
    test.done();
  },

  'title 3 should be accepted': function title3ShouldBeAccepted(test) {
    test.expect(1);
    // tests here
    test.ok(_markdown2.default.parse(_index2.default.ofString('### Title \n'), 0).isAccepted(), 'should be accepted.');
    test.done();
  },

  'title 3 should be retrieved': function title3ShouldBeRetrieved(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('### Title \n'), 0).value, [{ title: [{ text: " Title " }], level: 3 }], 'should be a title3.');
    test.done();
  },

  'title alternate 1 should be accepted': function titleAlternate1ShouldBeAccepted(test) {
    test.expect(1);
    // tests here
    test.ok(_markdown2.default.parse(_index2.default.ofString('Title\n====='), 0).isAccepted(), 'should be accepted.');
    test.done();
  },

  'title alternate 1 should be title1': function titleAlternate1ShouldBeTitle1(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('Title\n=====\n'), 0).value, [{ title: [{ text: "Title" }], level: 1 }], 'should be a title1.');
    test.done();
  },

  'title alternate 2 should be accepted': function titleAlternate2ShouldBeAccepted(test) {
    test.expect(1);
    // tests here
    test.ok(_markdown2.default.parse(_index2.default.ofString('Title\n-----'), 0).isAccepted(), 'should be accepted.');
    test.done();
  },

  'title alternate 2 should be title2': function titleAlternate2ShouldBeTitle2(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('Title\n-----'), 0).value, [{ title: [{ text: "Title" }], level: 2 }], 'should be a title2.');
    test.done();
  },

  'line should be accepted': function lineShouldBeAccepted(test) {
    test.expect(1);
    // tests here
    test.ok(_markdown2.default.parse(_index2.default.ofString('a simple test\n'), 0).isAccepted(), 'should be accepted.');
    test.done();
  },

  'line should be a simple test': function lineShouldBeASimpleTest(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('a simple test\n'), 0).value, [{ text: "a simple test" }], 'should be a simple test line.');
    test.done();
  },

  'bold line should be accepted': function boldLineShouldBeAccepted(test) {
    test.expect(1);
    // tests here
    test.ok(_markdown2.default.parse(_index2.default.ofString('**a simple test**\n'), 0).isAccepted(), 'should be accepted.');
    test.done();
  },

  'bold (1) line should be a simple test': function bold1LineShouldBeASimpleTest(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('**a simple test**\n'), 0).value, [{ bold: { text: "a simple test" } }], 'should be a simple test line.');
    test.done();
  },

  'bold (2) line should be a simple test': function bold2LineShouldBeASimpleTest(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('__a simple test__\n'), 0).value, [{ bold: { text: "a simple test" } }], 'should be a simple test line.');
    test.done();
  },

  'italic (1) line should be a simple test': function italic1LineShouldBeASimpleTest(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('*a simple test*\n'), 0).value, [{ italic: { text: "a simple test" } }], 'should be a simple test line.');
    test.done();
  },

  'italic (2) line should be a simple test': function italic2LineShouldBeASimpleTest(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('_a simple test_\n'), 0).value, [{ italic: { text: "a simple test" } }], 'should be a simple test line.');
    test.done();
  },

  'strike line should be a simple test': function strikeLineShouldBeASimpleTest(test) {
    test.expect(1);
    // tests here
    test.deepEqual(_markdown2.default.parse(_index2.default.ofString('~~a simple test~~\n'), 0).value, [{ strike: { text: "a simple test" } }], 'should be a simple test line.');
    test.done();
  }
};
//# sourceMappingURL=markdown_test.js.map